; Ŀ
;  Procedure:  EditRec()                                                   
;  Purpose  :  Edit the current record of the current table with a WAIT    
;  RECORD.  This procedure assumes that a table with a PFL lock is in      
;  CoEdit mode with IMAGERIGHTS READONLY set.  If the record cannot be     
;  locked, set WaitMessage (a message variable private to the calling      
;  procedure) with a value indicating the problem and return.              
;                                                                          
;    This script is part of a sample application described in the          
;    October 1993 issue of Paradox Information.  This script was written   
;    by Cary Jensen of Data Works of Houston.                              
;                                                                          
;    This script is for demonstration purposes only.  No representation    
;    is made concerning the appropriateness of this script for any other   
;    purpose.  If you use this script you agree to hold its author and     
;    Data Works of Houston free from any claim arising out of the use or   
;    misuse of this script.                                                
; ͵
;                              Cary Jensen                                 
;                          Data Works of Houston                           
;                             CIS 76307,1533                               
;                             (713) 359-3311                               
; ͵
; 
PROC EditRec()
PRIVATE Choice

;Lock the record.
IF NOT RECORDSTATUS("Locked")
  THEN
    LOCKRECORD
    IF NOT Retval
      THEN
        WaitMessage = "This record in use by another user."
        IMAGERIGHTS READONLY
        RETURN
    ENDIF
ENDIF

;Permit changes to the record.
IMAGERIGHTS
;Set the record to a modifed, not yet posted status
[] = []

WaitMessage = "Editing record shown..."

WHILE True
  WAIT RECORD
    Prompt "[F2]-Save     [Ctrl-U]-Cancel     [Del]-Delete     [Esc]-Exit"
    MESSAGE WaitMessage
    UNTIL "F2","UNDO","DOS","DOSBIG","DEL","ESC"

    WaitMessage = ""

    SWITCH
      CASE Retval = "F2":
        IF IsFieldView()
          THEN
            DO_IT!
            LOOP
        ENDIF
        ;Attempt to post the changes.
        LOCKRECORD
        IF RECORDSTATUS("KeyViol")
          THEN
            WaitMessage = "Record key conflicts with existing record.  "+
                              "Change key or delete this record."
            ;Exit the keyviol state.
            [] = []
            LOOP
        ENDIF
        ;Return to readonly state and return to the WAIT TABLE.
        IMAGERIGHTS READONLY
        RETURN

      CASE Retval = "UNDO" OR Retval = "ESC":
        ;Verify.
        SHOWMENU
          "Cancel" :"Do not undo changes to this record and return to editing",
          "Ok"     :"Undo the changes to this record."
          TO Choice
        IF NOT Choice = "Ok"
          THEN
            LOOP
          ELSE
            UNDO
            IMAGERIGHTS READONLY
            RETURN
        ENDIF


      CASE Retval = "DEL":
        ;Get confirmation if not in field view.
        IF ISFIELDVIEW()
          THEN DEL
          ELSE
            SHOWMENU
              "Cancel" :"Do not delete this record.",
              "Ok"     :"Delete this record."
              TO Choice
            IF Choice = "Ok"
              THEN
                DEL
                IMAGERIGHTS READONLY
                RETURN
            ENDIF
        ENDIF

      OTHERWISE:
        BEEP
    ENDSWITCH
ENDWHILE
ENDPROC ; --- EditRec()
WRITELIB "Paradox" EditRec
RELEASE PROCS EditRec
